@@ -9,7 +9,7 @@ import spotipy
 from spotipy.oauth2 import SpotifyClientCredentials
 
 from spotify_dl.constants import VERSION
-from spotify_dl.scaffold import log, check_for_tokens, console
+from spotify_dl.scaffold import log, get_tokens, console
 from spotify_dl.spotify import fetch_tracks, parse_spotify_url, validate_spotify_url, get_item_name
 from spotify_dl.youtube import download_songs, default_filename, playlist_num_filename
 
@@ -20,7 +20,7 @@ def spotify_dl():
     parser.add_argument('-l', '--url', action="store",
                         help="Spotify Playlist link URL", type=str, nargs='+', required=True)
     parser.add_argument('-o', '--output', type=str, action='store',
-                        help='Specify download directory.', required=False)
+                        help='Specify download directory.', required=False, default = ".")
     parser.add_argument('-d', '--download', action='store_true',
                         help='Download using youtube-dl', default=True)
     parser.add_argument('-f', '--format_str', type=str, action='store',
@@ -65,10 +65,12 @@ def spotify_dl():
     console.log(f"Starting spotify_dl [bold green]v{VERSION}[/bold green]")
     log.debug('Setting debug mode on spotify_dl')
 
-    if not check_for_tokens():
+    tokens = get_tokens()
+    if tokens is None:
         sys.exit(1)
 
-    sp = spotipy.Spotify(auth_manager=SpotifyClientCredentials())
+    C_ID, C_SECRET = tokens
+    sp = spotipy.Spotify(auth_manager=SpotifyClientCredentials(client_id=C_ID,client_secret=C_SECRET))
     log.debug('Arguments: {}'.format(args))
 
     for url in args.url:
@@ -77,21 +79,24 @@ def spotify_dl():
 
         if not valid_item:
             sys.exit(1)
-
+        
+        
+        
         if args.output:
             item_type, item_id = parse_spotify_url(url)
             directory_name = get_item_name(sp, item_type, item_id)
             save_path = Path(PurePath.joinpath(Path(args.output), Path(directory_name)))
             save_path.mkdir(parents=True, exist_ok=True)
             console.print(f"Saving songs to [bold green]{directory_name}[/bold green] directory")
-
-        songs = fetch_tracks(sp, item_type, url)
+            songs = fetch_tracks(sp, item_type, url)
+        else:
+            songs = {}
         if args.download is True:
             file_name_f = default_filename
             if args.keep_playlist_order:
                 file_name_f = playlist_num_filename
-
-            download_songs(songs, save_path, args.format_str, args.skip_mp3, args.keep_playlist_order, args.no_overwrites, file_name_f)
+            if save_path is not None:
+                download_songs(songs, save_path, args.format_str, args.skip_mp3, args.keep_playlist_order, args.no_overwrites, file_name_f)
 
 
 if __name__ == '__main__':
